/**********************************************************
 *
 *  The section below contains the database schema
 *  changes from ITIM 4.6 Base to FP14 (L3_itim_46_5763)
 *
 **********************************************************/

ALTER TABLE AUDIT_EVENT
  MODIFY ENTITY_NAME  VARCHAR2(1000)
  MODIFY INITIATOR_NAME  VARCHAR2(1000)
  MODIFY CONTAINER_NAME  VARCHAR2(1000);

ALTER TABLE AUDIT_MGMT_TARGET
  MODIFY TARGET_ENTITY_NAME  VARCHAR2(1000);

ALTER TABLE AUDIT_MGMT_PROVISIONING
  MODIFY OWNER_NAME  VARCHAR2(1000)
  MODIFY SERVICE_NAME  VARCHAR2(1000);

ALTER TABLE AUDIT_MGMT_DELEGATE
  MODIFY DELEGATE_NAME  VARCHAR2(1000);

/**********************************************************
 *
 *  The section below contains the database schema
 *  changes from FP14 to FP21 (L3_itim_46_5778)
 *
 **********************************************************/
ALTER TABLE REMOTE_SERVICES_REQUESTS
  MODIFY DATA CLOB;

/**********************************************************
 *
 *  The section below contains the database schema
 *  changes from FP21 to FP25 (L3_itim_46_5791)
 *
 * Note: Refer to upgradeData.ddl for the DB data changes
 *
 **********************************************************/

ALTER TABLE RESOURCE_PROVIDERS ADD SERVER VARCHAR2(20);


CREATE TABLE SUMMARY_ORDER (
    RESULT_SUMMARY varchar2(2) NOT NULL,
    RESULT_SEVERITY NUMBER NOT NULL UNIQUE,
    CONSTRAINT Uni_ResultSummary PRIMARY KEY(RESULT_SUMMARY)
    USING INDEX TABLESPACE enrole_indexes,
    CONSTRAINT Range_Value CHECK (RESULT_SEVERITY >= 0 AND RESULT_SEVERITY <= 100)
)
TABLESPACE enrole_data;



/**********************************************************
 *
 *  The section below contains the database schema
 *  changes from FP25 to FP33 (L3_itim_46_5795)
 *
 **********************************************************/

ALTER TABLE ENTITLEMENT_PROVISIONINGPARAMS
  MODIFY ATTRIBUTEVALUE  VARCHAR(4000);




/**********************************************************
 *
 *  The section below contains the database schema
 *  changes from the latest 4.6 fix pack level (FP33) to ITIM 5.0
 *
 **********************************************************/

ALTER TABLE RESOURCE_PROVIDERS
  MODIFY SERVER  VARCHAR2(255);


ALTER TABLE REMOTE_RESOURCES_RECONS
  ADD  RECON_NAME VARCHAR (300)
  ADD  DESCRIPTION VARCHAR (300);

ALTER TABLE REMOTE_RESOURCES_RECON_QUERIES
  ADD SUPPORT_DATA_ONLY NUMBER;


ALTER TABLE PO_TOPIC_TABLE
  MODIFY SERVER  VARCHAR(255);

ALTER TABLE SCHEDULED_MESSAGE
  ADD SMALL_MESSAGE VARCHAR2(4000)
  MODIFY SERVER  VARCHAR2(255);


ALTER TABLE PROCESS
  ADD SUBJECT_ACCESS_ID VARCHAR2(2000)
  ADD SUBJECT_ACCESS_NAME VARCHAR2(100)
  ADD SHORT_DETAIL VARCHAR2(4000);


ALTER TABLE ACTIVITY
  ADD SHORT_DETAIL VARCHAR2(4000);



ALTER TABLE PROCESSLOG
  ADD SMALL_NEW_DATA VARCHAR2(4000);


CREATE TABLE SERVICE_ACCOUNT_MAPPING (
  SERVICEPROFILE VARCHAR (255) NOT NULL,
  ACCOUNTPROFILE VARCHAR (255) NOT NULL,
  PRIMARY KEY (SERVICEPROFILE, ACCOUNTPROFILE)
  USING INDEX TABLESPACE enrole_indexes
)
TABLESPACE enrole_data;

ALTER TABLE RECONCILIATION
  ADD ACTIVITY_ID NUMBER(20);

ALTER TABLE RECONCILIATION_INFO
  ADD HANDLE NUMBER(20);

/* ALTER TABLE POLICY_ANALYSIS_ERROR
  MODIFY ERROR_MESSAGE  LONG NOT NULL;*/

ALTER TABLE AUDIT_MGMT_PROVISIONING
  ADD access_name VARCHAR (1000)
  ADD access_dn VARCHAR (1000);

create table RECERTIFICATIONLOG
(
  PROCESS_ID NUMBER(20) NOT NULL,
  ACTIVITY_ID NUMBER(20) NOT NULL,
  ENTITY_DN VARCHAR(255),
  ACCESS_DN VARCHAR(255),
  ACCOUNT_ID VARCHAR(100),
  ACCOUNT_OWNER_NAME VARCHAR(100),
  ACCOUNT_OWNER VARCHAR(255),
  ACCESS_NAME VARCHAR(100),
  ACCESS_TYPE VARCHAR(100),
  TYPE VARCHAR(2) NOT NULL,
  SERVICE VARCHAR(255),
  SERVICE_NAME VARCHAR(100),
  SERVICE_PROFILE VARCHAR(100),
  PARTICIPANT VARCHAR(255),
  PARTICIPANT_NAME VARCHAR(100),
  PARTICIPANT_ID VARCHAR(100),
  RECERT_RESULT VARCHAR(2),
  ACTION VARCHAR(2),
  COMMENTS VARCHAR(2000),
  STARTED VARCHAR(50),
  COMPLETED VARCHAR(50),
  RESULT_SUMMARY VARCHAR(2),
  TENANT VARCHAR(255),
  CONSTRAINT RECERT_PK PRIMARY KEY(PROCESS_ID, ACTIVITY_ID)
  USING INDEX TABLESPACE enrole_indexes
)
TABLESPACE enrole_data;

CREATE TABLE SCRIPT  (
		  TYPE CHAR(1) NOT NULL,
		  ID VARCHAR(50) NOT NULL,
		  JOIN_ORDER NUMBER NOT NULL,
		  PERSON_ATTRIBUTE VARCHAR(100) NOT NULL,
		  FIRST_LAST NUMBER,
		  CONCATENATE_CHAR CHAR(10),
		  CONSTRAINT SCRIPT_PK PRIMARY KEY(TYPE, ID, JOIN_ORDER)
  		  USING INDEX TABLESPACE enrole_indexes
) TABLESPACE enrole_data;

DROP VIEW ROOTPROCESSVIEW;

CREATE VIEW ROOTPROCESSVIEW (ID, TYPE, REQUESTER) AS
(
  SELECT ID, TYPE, REQUESTER
  FROM PROCESS
  WHERE  PROCESS.ROOT_PROCESS_ID  = 0
  OR PROCESS.ROOT_PROCESS_ID  = PROCESS.ID
  AND PROCESS.TYPE IN ('OP','AA','AC','UA','UC','UD','US','UR','UO','SR','OA','OC','AD',
            'AS','AR','AP','LO','AO','LS','LR','LP','LD','MS','MR','MD','DA','DC',
            'DD','PA','PC','PD','SA','SC','SD','PS','EN','RC','PE','LC','CP','EP','RP','SM','MA','EA','ER','HR')
);

DROP VIEW SUBPROCESSVIEW;

CREATE VIEW SUBPROCESSVIEW (ROOT_PROCESS_ID, SUBMITTED, COMPLETED, SUBJECT_PROFILE,
  SUBJECT_SERVICE, SUBJECT, TYPE, REQUESTER, RESULT_SUMMARY)
AS
(
  SELECT ROOT_PROCESS_ID, SUBMITTED, COMPLETED, SUBJECT_PROFILE,
    SUBJECT_SERVICE, SUBJECT, TYPE, REQUESTER,
    CASE
      WHEN RESULT_SUMMARY = '' THEN 'PE'
      ELSE RESULT_SUMMARY
    END as RESULT_SUMMARY
  FROM PROCESS
  WHERE TYPE IN ('OA', 'OC', 'AD', 'AS', 'AR', 'AP')
);

DROP VIEW PENDING_APPROVAL;

CREATE VIEW PENDING_APPROVAL (PROCESSID, RESULT_SUMMARY)
AS
(
  SELECT PROCESS.ID,
    CASE
      WHEN WORKITEM.LOCK_OWNER IS NULL THEN ACTIVITY.RESULT_SUMMARY
      ELSE 'LK'
    END
  FROM PROCESS, ACTIVITY, WORKITEM
  WHERE WORKITEM.PROCESS_ID = PROCESS.ID AND WORKITEM.ACTIVITY_ID = ACTIVITY.ID
);

CREATE VIEW SUSPENDED_USERS (REQUESTEE, COMPLETED) AS
(
  SELECT PROCESS.REQUESTEE, MAX(PROCESS.COMPLETED)
  FROM PROCESS
  WHERE PROCESS.TYPE = 'US'
  GROUP BY PROCESS.REQUESTEE
);

CREATE VIEW SUSPENDED_ACCOUNT_OPERATIONS (REQUESTEE, SUBJECT_SERVICE, SUBJECT, SUBJECT_PROFILE, COMPLETED) AS
(
  SELECT PROCESS.REQUESTEE, PROCESS.SUBJECT_SERVICE, PROCESS.SUBJECT, PROCESS.SUBJECT_PROFILE, MAX(PROCESS.COMPLETED)
  FROM PROCESS
  WHERE PROCESS.TYPE = 'AS'
  GROUP BY PROCESS.REQUESTEE, PROCESS.SUBJECT_SERVICE, PROCESS.SUBJECT, PROCESS.SUBJECT_PROFILE
);

CREATE VIEW PROCESS_VIEW (ID, REQUESTER, REQUESTEE)
AS
(
  SELECT PROCESS.ID, NVL(PROCESS.REQUESTER, ' ') as REQUESTER, NVL(PROCESS.REQUESTEE, ' ') as REQUESTEE
  FROM PROCESS
);

CREATE TABLE MANUAL_SERVICE_RECON_ACCOUNTS (
  GLOBAL_ID VARCHAR(255) NOT NULL,
  ACCOUNTS CLOB,
  PRIMARY KEY (GLOBAL_ID)
  USING INDEX TABLESPACE enrole_indexes
)
TABLESPACE enrole_data;

CREATE TABLE VIEW_DEFINITION (
  ID INT NOT NULL,
  NAME VARCHAR(100),
  DESCRIPTION VARCHAR(2000),
  CONSTRAINT VIEW_DEFINITION_PK PRIMARY KEY(ID)
  USING INDEX TABLESPACE enrole_indexes
) TABLESPACE enrole_data;


CREATE TABLE TASKS_VIEWABLE (
  TASK_ID VARCHAR(255) NOT NULL,
  VIEW_ID INT NOT NULL,
  VIEWABLE CHAR(1) DEFAULT 'N' NOT NULL,
  CONSTRAINT TASKS_VIEWABLE_PK PRIMARY KEY(TASK_ID, VIEW_ID)
  USING INDEX TABLESPACE enrole_indexes,
  CONSTRAINT VIEW_ID_FK FOREIGN KEY (VIEW_ID) REFERENCES VIEW_DEFINITION (ID)
) TABLESPACE enrole_data;

ALTER TABLE BULK_DATA_SERVICE
  ADD filename VARCHAR2(255)
  ADD DESCNAME VARCHAR2(255);

ALTER TABLE MIGRATION_STATUS
  ADD SERVICEID NUMBER(20);

CREATE TABLE COMMON_TASKS  (
	PERSONA VARCHAR(100) NOT NULL,
	TASK_ID VARCHAR(255) NOT NULL,
	CONSTRAINT COMMON_TASKS_PK PRIMARY KEY(PERSONA, TASK_ID)
	USING INDEX TABLESPACE enrole_indexes
) TABLESPACE enrole_data;

CREATE TABLE ACTIVITY_LOCK (
  PROCESS_ID NUMBER(20) NOT NULL,
  ACTIVITY_ID NUMBER(20) NOT NULL,
  SERVER varchar2(255) NOT NULL,
  THREAD_ID NUMBER(20) NOT NULL,
  LOCK_COUNT NUMBER(10),
  CONSTRAINT ACTIVITY_LOCK_PFK FOREIGN KEY(PROCESS_ID) REFERENCES PROCESS(ID),
  CONSTRAINT ACTIVITY_LOCK_AFK FOREIGN KEY(ACTIVITY_ID) REFERENCES ACTIVITY(ID),
  CONSTRAINT ACTIVITY_LOCK_PK PRIMARY KEY(PROCESS_ID, ACTIVITY_ID, SERVER, THREAD_ID) USING INDEX TABLESPACE enrole_indexes
) TABLESPACE enrole_data;


CREATE INDEX SCH_MSG_SVR on SCHEDULED_MESSAGE (SERVER ASC) TABLESPACE enrole_indexes;

CREATE INDEX PROCESS_SUB_X on PROCESS (SUBMITTED DESC, PARENT_ID ASC) TABLESPACE enrole_indexes;

CREATE INDEX PROCESS_ID_ST on PROCESS (ID ASC, STATE ASC) TABLESPACE enrole_indexes;

CREATE INDEX PROCESSDATA_ID_DEF on PROCESSDATA (PROCESS_ID ASC, DEF_ID ASC, VALUE_LAST_MODIFIED ASC) TABLESPACE enrole_indexes;

ALTER TABLE RESOURCE_PROVIDERS
  ADD RESOURCE_TEST_STATUS NUMBER
  ADD LAST_TEST_STATUS_TIME DATE;
create index AUDIT_REPORT1 on AUDIT_EVENT (TIMESTAMP, ITIM_EVENT_CATEGORY) TABLESPACE enrole_indexes;

/**********************************************************
 *
 *  The section below contains the database schema
 *  changes from ITIM 5.0 FP01 to FP02
 *
 **********************************************************/

CREATE TABLE PASSWORD_SYNCH (
	ACTIVITY_ID NUMBER(20) NOT NULL,
	ACCOUNT_DN VARCHAR2(512),
	TIME_REQUESTED VARCHAR2(50),
	PASSWORD VARCHAR2(500),

	CONSTRAINT PWD_SYNCH_PK PRIMARY KEY(ACTIVITY_ID)
	USING INDEX
	TABLESPACE enrole_indexes
)
TABLESPACE enrole_data;

CREATE INDEX PS_ACCDN_X ON PASSWORD_SYNCH(ACCOUNT_DN)
TABLESPACE enrole_indexes;
CREATE INDEX PS_TIME_X ON PASSWORD_SYNCH(TIME_REQUESTED)
TABLESPACE enrole_indexes;

/**********************************************************
 *
 *  The section below contains the database schema
 *  changes in ITIM 5.1
 *
 **********************************************************/

CREATE TABLE ROLE_INHERITANCE (
  ASCENDENT VARCHAR2(2000) NOT NULL,
  DESCENDENT VARCHAR2(2000) NOT NULL,
  CONSTRAINT ROLE_INH_PK PRIMARY KEY(ASCENDENT, DESCENDENT)
  USING INDEX
	TABLESPACE enrole_indexes
) TABLESPACE enrole_data;;

CREATE INDEX ROLE_INH_ASC_IDX ON ROLE_INHERITANCE (ASCENDENT)
TABLESPACE enrole_indexes;

CREATE INDEX ROLE_INH_DSC_IDX ON ROLE_INHERITANCE (DESCENDENT)
TABLESPACE enrole_indexes;

CREATE TABLE USERRECERT_HISTORY (
  ID NUMBER(20) NOT NULL,
  PROCESS_ID NUMBER(20) NOT NULL,
  ACTIVITY_ID NUMBER(20) NOT NULL,
  PERSON_DN VARCHAR2(255),
  PERSON_NAME VARCHAR2(240),
  PERSON_PROFILE VARCHAR2(128),
  PERSON_EMAIL VARCHAR2(240),
  PERSON_CUSTOM_DISPLAY VARCHAR2(240),
  PERSON_STATUS INTEGER,
  PERSON_CONTAINER_DN VARCHAR2(255),
  PERSON_CONTAINER_NAME VARCHAR2(128),
  POLICY_DN VARCHAR2(255),
  POLICY_NAME VARCHAR2(240),
  SUBMITTED_DATE VARCHAR2(50),
  TIMEOUT SMALLINT,
  CONSTRAINT USERRECERT_PK PRIMARY KEY (ID) USING INDEX TABLESPACE enrole_indexes
) TABLESPACE enrole_data;

ALTER TABLE USERRECERT_HISTORY ADD CONSTRAINT USERRECERT_PROC_FK FOREIGN KEY (PROCESS_ID) REFERENCES PROCESS (ID) ON DELETE CASCADE;
ALTER TABLE USERRECERT_HISTORY ADD CONSTRAINT USERRECERT_ACTV_FK FOREIGN KEY (ACTIVITY_ID) REFERENCES ACTIVITY (ID) ON DELETE CASCADE;

CREATE INDEX URH_SUBMITTED ON USERRECERT_HISTORY (SUBMITTED_DATE ASC) TABLESPACE enrole_indexes;

CREATE TABLE USERRECERT_ROLE (
  ID NUMBER(20) NOT NULL,
  RECERT_ID NUMBER(20) NOT NULL,
  ROLE_DN VARCHAR2(255) NOT NULL,
  ROLE_NAME VARCHAR2(240),
  ROLE_DESCRIPTION VARCHAR2(500),
  DECISION CHAR(2),
  CONSTRAINT USERRECERT_ROLE_PK PRIMARY KEY (ID) USING INDEX TABLESPACE enrole_indexes
) TABLESPACE enrole_data;

ALTER TABLE USERRECERT_ROLE ADD CONSTRAINT USERRECERT_ROLE_FK FOREIGN KEY (RECERT_ID) REFERENCES USERRECERT_HISTORY (ID) ON DELETE CASCADE;

CREATE INDEX URR_ID_DEC ON USERRECERT_ROLE (RECERT_ID ASC, DECISION ASC) TABLESPACE enrole_indexes;

CREATE TABLE USERRECERT_ACCOUNT (
  ID NUMBER(20) NOT NULL,
  RECERT_ID NUMBER(20) NOT NULL,
  ACCOUNT_DN VARCHAR2(255) NOT NULL,
  ACCOUNT_UID VARCHAR2(240) NOT NULL,
  SERVICE_DN VARCHAR2(255) NOT NULL,
  SERVICE_NAME VARCHAR2(240),
  SERVICE_DESCRIPTION VARCHAR2(240),
  DECISION CHAR(2),
  CONSTRAINT USERRECERT_ACCT_PK PRIMARY KEY (ID) USING INDEX TABLESPACE enrole_indexes
) TABLESPACE enrole_data;

ALTER TABLE USERRECERT_ACCOUNT ADD CONSTRAINT USERRECERT_ACCT_FK FOREIGN KEY (RECERT_ID) REFERENCES USERRECERT_HISTORY (ID) ON DELETE CASCADE;

CREATE INDEX URA_ID_DEC ON USERRECERT_ACCOUNT (RECERT_ID ASC, DECISION ASC) TABLESPACE enrole_indexes;

CREATE TABLE USERRECERT_GROUP (
  ID NUMBER(20) NOT NULL,
  RECERT_ID NUMBER(20) NOT NULL,
  ACCOUNT_ID NUMBER(20) NOT NULL,
  GROUP_DN VARCHAR2(500) NOT NULL,
  GROUP_NAME VARCHAR2(240),
  GROUP_DESCRIPTION VARCHAR2(500),
  DECISION CHAR(2),
  CONSTRAINT USERRECERT_GRP_PK PRIMARY KEY (ID) USING INDEX TABLESPACE enrole_indexes
) TABLESPACE enrole_data;

ALTER TABLE USERRECERT_GROUP ADD CONSTRAINT USERRECERT_GRP_FK FOREIGN KEY (RECERT_ID) REFERENCES USERRECERT_HISTORY (ID);
ALTER TABLE USERRECERT_GROUP ADD CONSTRAINT USERRECERT_GA_FK FOREIGN KEY (ACCOUNT_ID) REFERENCES USERRECERT_ACCOUNT (ID) ON DELETE CASCADE;

CREATE INDEX URG_ID_DEC ON USERRECERT_GROUP (RECERT_ID ASC, ACCOUNT_ID DESC, DECISION ASC) TABLESPACE enrole_indexes;

ALTER TABLE PROCESSLOG ADD REQUESTOR_DN VARCHAR2(1000);

CREATE TABLE RECERTIFIER_DETAILS_INFO (
  DN VARCHAR(255) NOT NULL,
  RECERTIFIER_TYPE VARCHAR(255),
  RECERTIFIER_NAME VARCHAR(255),
  CONSTRAINT RECERT_DETAILS_PK PRIMARY KEY (DN) USING INDEX TABLESPACE enrole_indexes
) TABLESPACE enrole_data;

CREATE TABLE SOD_POLICY (
		ID NUMBER(20) NOT NULL,
		GLOBAL_ID NUMBER(20) NOT NULL,
		NAME VARCHAR2(256),
		DESCRIPTION VARCHAR2(500),
		BUSINESS_UNIT_NAME VARCHAR2(256),
		ENABLED CHAR(1),
		DN VARCHAR2(2000),
		VERSION NUMBER(20) NOT NULL,
		CONSTRAINT SP_PK PRIMARY KEY (ID)
	)
	TABLESPACE enrole_data;

CREATE TABLE SOD_RULE (
		ID NUMBER(20) NOT NULL,
		POLICY_ID NUMBER(20) NOT NULL,
		GLOBAL_ID NUMBER(20) NOT NULL,
		NAME VARCHAR2(500),
		DESCRIPTION VARCHAR2(500),
		CARDINALITY SMALLINT,
		VERSION NUMBER(20) NOT NULL,
		CONSTRAINT SPR_PK PRIMARY KEY (ID),
		CONSTRAINT SPR_FK FOREIGN KEY (POLICY_ID) REFERENCES SOD_POLICY (ID)
	)
	TABLESPACE enrole_data;

CREATE TABLE SOD_OWNER (
		ID NUMBER(20) NOT NULL,
		POLICY_ID NUMBER(20) NOT NULL,
		OWNER_NAME VARCHAR2(256),
		BUSINESS_UNIT_NAME VARCHAR2(256),
		TYPE VARCHAR2(2),
		DN VARCHAR2(2000),
		CONSTRAINT SPO_PK PRIMARY KEY (ID),
		CONSTRAINT SPO_FK FOREIGN KEY (POLICY_ID) REFERENCES SOD_POLICY (ID)
	)
	TABLESPACE enrole_data;

CREATE TABLE SOD_RULE_ROLE (
		ID NUMBER(20) NOT NULL,
		POLICY_RULE_ID NUMBER(20) NOT NULL,
		GLOBAL_ID NUMBER(20) NOT NULL,
		NAME VARCHAR2(256),
		DESCRIPTION VARCHAR2(500),
		BUSINESS_UNIT_NAME VARCHAR2(256),
		DN VARCHAR2(2000),
		CONSTRAINT SPRR_PK PRIMARY KEY (ID),
		CONSTRAINT SPRR_FK FOREIGN KEY (POLICY_RULE_ID) REFERENCES SOD_RULE (ID)
	)
	TABLESPACE enrole_data;

CREATE TABLE SOD_VIOLATION_HISTORY (
		ID NUMBER(20) NOT NULL,
		POLICY_GLOBAL_ID NUMBER(20) NOT NULL,
		RULE_GLOBAL_ID NUMBER(20) NOT NULL,
		PERSON_GLOBAL_ID NUMBER(20) NOT NULL,
		PERSON_NAME VARCHAR2(256),
		PERSON_BU VARCHAR2(256),
		PERSON_DN VARCHAR2(2000),
		PROCESS_ID NUMBER(20),
		ADMIN_NAME VARCHAR2(256),
		ADMIN_BU VARCHAR2(256),
		ADMIN_DN VARCHAR2(2000),
		ADMIN_NOTES VARCHAR2(4000),
		STATUS CHAR(1),
		TS NUMBER(20) NOT NULL,
		CONSTRAINT SVIOHIST_PK PRIMARY KEY (ID)
	)
	TABLESPACE enrole_data;

CREATE TABLE SOD_VIOLATION_STATUS (
		ID NUMBER(20) NOT NULL,
		POLICY_GLOBAL_ID NUMBER(20) NOT NULL,
		RULE_GLOBAL_ID NUMBER(20) NOT NULL,
		PERSON_GLOBAL_ID NUMBER(20) NOT NULL,
		PERSON_NAME VARCHAR2(256),
		PERSON_BU VARCHAR2(256),
		PERSON_DN VARCHAR2(2000),
		PROCESS_ID NUMBER(20),
		ADMIN_NAME VARCHAR2(256),
		ADMIN_BU VARCHAR2(256),
		ADMIN_DN VARCHAR2(2000),
		ADMIN_NOTES VARCHAR2(4000),
		STATUS CHAR(1),
		TS NUMBER(20) NOT NULL,
		EVAL_TS NUMBER(20) NOT NULL,
		CONSTRAINT SVIOSTAT_PK PRIMARY KEY (ID)
	)
	TABLESPACE enrole_data;

CREATE TABLE SOD_VIOLATION_ROLE_MAP (
		ID NUMBER(20) NOT NULL,
		VIOLATION_ID NUMBER(20) NOT NULL,
		RULEROLE VARCHAR2(2000),
		PERSONROLE VARCHAR2(2000),
		CONSTRAINT SPRVR_PK PRIMARY KEY (ID),
		CONSTRAINT SPRVR_FK FOREIGN KEY (VIOLATION_ID) REFERENCES SOD_VIOLATION_HISTORY (ID)
	)
	TABLESPACE enrole_data;
CREATE INDEX SP_1 ON SOD_POLICY (GLOBAL_ID ASC, VERSION DESC) TABLESPACE enrole_indexes;
CREATE INDEX SR_1 ON SOD_RULE (GLOBAL_ID ASC, POLICY_ID ASC) TABLESPACE enrole_indexes;
CREATE INDEX SVS_1 ON SOD_VIOLATION_STATUS (POLICY_GLOBAL_ID ASC, EVAL_TS DESC) TABLESPACE enrole_indexes;
CREATE INDEX SVS_2 ON SOD_VIOLATION_STATUS (PERSON_GLOBAL_ID ASC, RULE_GLOBAL_ID ASC) TABLESPACE enrole_indexes;
CREATE INDEX SVS_3 ON SOD_VIOLATION_STATUS (RULE_GLOBAL_ID ASC, STATUS ASC, ID ASC) TABLESPACE enrole_indexes;
CREATE INDEX SVRM_1 ON SOD_VIOLATION_ROLE_MAP (VIOLATION_ID ASC, PERSONROLE ASC, RULEROLE ASC) TABLESPACE enrole_indexes;
ALTER TABLE SOD_VIOLATION_STATUS ADD CONSTRAINT SVS_UC UNIQUE (RULE_GLOBAL_ID, PERSON_GLOBAL_ID);

CREATE INDEX RESPROVSTATUSX ON RESOURCE_PROVIDERS (RESOURCE_STATUS ASC, RESTART_TIME ASC, PROVIDER_ID ASC) TABLESPACE enrole_indexes;
CREATE INDEX LCR_CHILD_ID_X ON LCR_INPROGRESS_TABLE (CHILD_ID ASC) TABLESPACE enrole_indexes;
CREATE INDEX PROCESS_PACT_ID_X ON PROCESS (PARENT_ACTIVITY_ID ASC, ID DESC) TABLESPACE enrole_indexes;
CREATE INDEX PROCESS_USERREQ_X ON PROCESS (REQUESTER ASC, PARENT_ID ASC, TENANT ASC) TABLESPACE enrole_indexes;
CREATE INDEX ACTIVITY_PID_X ON ACTIVITY (PROCESS_ID DESC) TABLESPACE enrole_indexes;
CREATE INDEX PROCESSLOG_PID_X ON PROCESSLOG (PROCESS_ID ASC) TABLESPACE enrole_indexes;
CREATE INDEX PROCESSLOG_AID_X ON PROCESSLOG (ACTIVITY_ID ASC) TABLESPACE enrole_indexes;
CREATE INDEX ACTIVITY_LOCK_PIDX ON ACTIVITY_LOCK (PROCESS_ID ASC) TABLESPACE enrole_indexes;
CREATE INDEX RECON_COMPLETED ON RECONCILIATION (COMPLETED ASC) TABLESPACE enrole_indexes;
CREATE INDEX RECON_INFO_ACCT_ID ON RECONCILIATION_INFO (ACCOUNTID ASC, RECONID DESC) TABLESPACE enrole_indexes;
CREATE INDEX RECON_INFO_ID_OP ON RECONCILIATION_INFO (RECONID ASC, OPERATION ASC) TABLESPACE enrole_indexes;
CREATE INDEX WF_CALLBACK_PID_X ON WORKFLOW_CALLBACK (PROCESS_ID ASC) TABLESPACE enrole_indexes;
CREATE INDEX POL_ANALY_ACC_X ON POLICY_ANALYSIS (LAST_ACCESSED ASC, ANALYSIS_ID) TABLESPACE enrole_indexes;
CREATE INDEX ACCT_CHANGE_PREV_X ON ACCT_CHANGE (POLICY_ANALYSIS_ID ASC, OPERATION_TYPE ASC, REASON ASC) TABLESPACE enrole_indexes;
CREATE INDEX ADT_EVENT_PID_ID_X ON AUDIT_EVENT (WORKFLOW_PROCESS_ID ASC, ID DESC) TABLESPACE enrole_indexes;
CREATE INDEX ADT_MGMT_TGT_ID_X ON AUDIT_MGMT_TARGET (EVENT_ID ASC) TABLESPACE enrole_indexes;
CREATE INDEX ADT_MGMT_PROV_ID_X ON AUDIT_MGMT_PROVISIONING (EVENT_ID ASC) TABLESPACE enrole_indexes;
CREATE INDEX ADT_MGMT_DEL_ID_X ON AUDIT_MGMT_DELEGATE (EVENT_ID ASC) TABLESPACE enrole_indexes;
CREATE INDEX BDS_SID ON BULK_DATA_STORE (SERVICEID DESC) TABLESPACE enrole_indexes;
CREATE INDEX BDI_SID ON BULK_DATA_INDEX (STOREID DESC) TABLESPACE enrole_indexes;
CREATE INDEX BDI_DOID ON BULK_DATA_INDEX (DATAOBJECTID DESC) TABLESPACE enrole_indexes;
CREATE INDEX TASKS_VIEWABLE_X ON TASKS_VIEWABLE (VIEW_ID ASC, VIEWABLE ASC, TASK_ID ASC) TABLESPACE enrole_indexes;

ALTER TABLE SOD_POLICY MODIFY DESCRIPTION VARCHAR2(1024);
ALTER TABLE SOD_RULE_ROLE MODIFY DESCRIPTION VARCHAR2(1024);
ALTER TABLE USERRECERT_ROLE MODIFY ROLE_DESCRIPTION VARCHAR2(1024);
ALTER TABLE USERRECERT_GROUP MODIFY GROUP_DESCRIPTION VARCHAR2(1024);

ALTER TABLE ENTITLEMENT_PROVISIONINGPARAMS
  ADD  SERVICETARGETNAME VARCHAR (255)
  ADD  SERVICE_DN VARCHAR (255);

/**
--
-- PENDING_REQUESTS
--
-- This table keeps the pending deprovisioning and suspend requests.
--
-- PROCESS_ID - The process ID associated with the data
-- PERSON_DN  - The definition ID for the corresponding relevant data in process definition
-- SERVICE_DN - The activity ID associated with the data if there is any
-- ACCOUNT_DN - The definition ID for corresponding relevant data in process definition
-- PROCESS_TYPE - The process type
*/
CREATE TABLE PENDING_REQUESTS
(
  PROCESS_ID        NUMBER(20) NOT NULL,
  PERSON_DN         varchar2(2000),
  SERVICE_DN        varchar2(2000),
  ACCOUNT_DN        varchar2(2000),
  PROCESS_TYPE      varchar2(2),
CONSTRAINT PENDING_REQS_FK FOREIGN KEY(PROCESS_ID)
  REFERENCES PROCESS(ID) ON DELETE CASCADE,
CONSTRAINT PENDING_REQS_PK PRIMARY KEY(PROCESS_ID) USING
  INDEX
  TABLESPACE enrole_indexes
)
TABLESPACE enrole_data;

CREATE INDEX PENDING_REQUESTS_FOR_ACCOUNT ON PENDING_REQUESTS (ACCOUNT_DN) TABLESPACE enrole_indexes;

ALTER TABLE ENTITY_COLUMN ADD COLUMN_LENGTH SMALLINT DEFAULT 255;